@@ -73,6 +73,9 @@ class Release(Framework.TestCase):
         self.assertEqual(self.release.prerelease, False)
         self.assertEqual(self.release.url, "https://api.github.com/repos/edhollandAL/PyGithub/releases/1210814")
         self.assertEqual(self.release.author._rawData['login'], "edhollandAL")
+        self.assertEqual(self.release.author.login, "edhollandAL")
+        self.assertEqual(self.release.author.id, 11922660)
+        self.assertEqual(self.release.author.type, "User")
         self.assertEqual(self.release.html_url, "https://github.com/edhollandAL/PyGithub/releases/tag/v1.25.2")
         self.assertEqual(self.release.created_at, datetime.datetime(2014, 10, 8, 1, 54))
         self.assertEqual(self.release.published_at, datetime.datetime(2015, 4, 24, 8, 36, 51))
