@@ -5,6 +5,7 @@
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2018 Steve Kowalik <steven@wedontsleep.org>                        #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
@@ -32,13 +33,9 @@ import github
 class Issue134(Framework.BasicTestCase):  # https://github.com/jacquev6/PyGithub/pull/134
     def testGetAuthorizationsFailsWhenAutenticatedThroughOAuth(self):
         g = github.Github(self.oauth_token)
-        raised = False
-        try:
+        with self.assertRaises(github.GithubException) as raisedexp:
             list(g.get_user().get_authorizations())
-        except github.GithubException, exception:
-            raised = True
-            self.assertEqual(exception.status, 404)
-        self.assertTrue(raised)
+        self.assertEqual(raisedexp.exception.status, 404)
 
     def testGetAuthorizationsSucceedsWhenAutenticatedThroughLoginPassword(self):
         g = github.Github(self.login, self.password)
